* An Energy-Economy Model to Evaluate the Future Energy Demand-Supply System
*                               in Indonesia
*                          Author : Agus Sugiyono
*                               January 1995

$OFFSYMXREF OFFSYMLIST OFFUELLIST OFFUELXREF
FILE FSAVE /EED7-5.OUT/;
PUT FSAVE;
PUT "* CASE : Discount rate 7.5 % *" /;

SETS
  T         Time period   /1990, 2000, 2010, 2020, 2030/
  TFIRST(T) First period
  TLAST(T)  Last period
  RG        Region        /JAV, SMT, KAL, OTH/
  ITR       Iteration     /1*3/

  AT All Technology
    /COA-I  Coal to Industry Sector
     COA-O  Coal to Other Sector
     GAS-I  Gas to Industry Sector
     GAS-T  Gas to Transportation Sector
     GAS-O  Gas to Other Sector
     OIL-I  Oil to Industry Sector
     OIL-T  Oil to Transportation Sector
     OIL-O  Oil to Other Sector
     BIO-O  Biomass Fuel to Other Sector
     COA-P  Electric from Coal
     GAS-P  Electric from Gas
     OIL-P  Electric from Crude Oil
     HYDRO  Electric from Hydropower
     GEOTR  Electric from Geothermal
     /

  ET(AT) Electricity Technology
    /COA-P, GAS-P, OIL-P, HYDRO, GEOTR/

  NT(AT) Nonelectric Technology
    /COA-I, COA-O, GAS-I, GAS-T, GAS-O, OIL-I, OIL-T, OIL-O, BIO-O/

  TCOA(AT) Coal Base Technology
    /COA-I, COA-O, COA-P/
  TGAS(AT) Gas Base Technology
    /GAS-I, GAS-T, GAS-O, OIL-P/
  TOIL(AT) Oil Base Technology
    /OIL-I, OIL-T, OIL-O, GAS-P/

  FOSS Fossil fuel for regional transportation
    /COAL, NGAS, COIL/

  EDM Electricity Sectoral Demand
    /ELE-I, ELE-T, ELE-O/

  NIND(AT)  Nonelectricity in Industry Sector
    /COA-I, GAS-I, OIL-I/
  NTRA(AT)  Nonelectricity in Transportation Sector
    /GAS-T, OIL-T/
  NOTH(AT)  Nonelectricity in Other Sector
    /COA-O, GAS-O, OIL-O, BIO-O/

SCALARS
  NYPER  Number of years per period             /10./
  BET    Discount factor                        /0.925/
  DK     Depreciation rate on capital per year  /0.10/

  A0     Initial level of total factor productivity     /1.0/
  GA0    Initial growth rate for technology per decade  /0.25/
  DELA   Decline rate of technology change per decade   /0.08/

  PFPF   Proportional factor of production function    /0.10/
  PFEC   Proportional factor of energy cost            /6500/
  PFFC   Proportional factor of foreign transp. cost   /900/
  PFDC   Proportional factor of domestic transp. cost  /90/

PARAMETERS
  R(RG) Rate of social time preference per year
    /JAV  .025 
     SMT  .020
     KAL  .020
     OTH  .025/

  K0(RG) Initial capital (Million 1990 US dollar)
    /JAV  107.86 
     SMT   86.74
     KAL   29.52
     OTH   25.75/
     
  I0(RG) Initial investment (Million 1990 US dollar)
    /JAV  23.477
     SMT  10.402 
     KAL   2.306
     OTH   2.900/

  C0(RG) Initial consumption (Million 1990 US dollar)
    /JAV  5.729 
     SMT  2.539
     KAL  0.563
     OTH  0.708/

  N0(RG) Initial nonelectric energy
  E0(RG) Initial electric energy
  L0(RG) Initial population

  Y0(RG) Initial productivity (Million 1990 US dollar)
    /JAV  56.53
     SMT  27.21
     KAL   9.88
     OTH   7.15/

  ESUB(RG) Production value share of energy
    /JAV  0.30
     SMT  0.12
     KAL  0.12
     OTH  0.30/

  KPVS(RG) Capital value share
    /JAV  0.30
     SMT  0.30
     KAL  0.30
     OTH  0.30/

  ELVS(RG) Elasticity of electricity in industry
    /JAV  0.40
     SMT  0.40
     KAL  0.40
     OTH  0.40/

  A(RG) Output scaling factor

  RESBIO(RG) Limit of biomass use per annum (MTOE)
    /JAV  10.0
     SMT  14.0
     KAL  15.0
     OTH   8.0/

  RESGEO(RG) Limit of geothermal use per annum (MTOE)
    /JAV  4.113
     SMT  2.585
     KAL  0.001
     OTH  1.792/

  RESHYD(RG) Limit of hydropower use per annum (MTOE)
    /JAV   2.215
     SMT   8.226
     KAL  11.390
     OTH  17.718/

  EATRN(RG) Income elasticity in transportation sector
    /JAV  0.403
     SMT  0.403
     KAL  0.403
     OTH  0.403/

  EAPUB(RG) Income elasticity in others sector
    /JAV  0.312
     SMT  0.312
     KAL  0.312
     OTH  0.312/

  EFF0(RG) Final electric conversion efficiency
    /JAV    3.0
     SMT    2.8
     KAL    2.7
     OTH    2.3/

  EFFA(RG) Constant term of electric conversion eff.
    /JAV  7.3333
     SMT  7.3333
     KAL  7.3333
     OTH  7.3333/

  EFFB(RG) Time dependence term of electric conversion eff.
    /JAV  -0.003
     SMT  -0.003
     KAL  -0.003
     OTH  -0.003/

  GL0(RG) Population after 2100
    /JAV  161
     SMT  103
     KAL   27
     OTH   75/

  GLA(RG) Constant term of population
    /JAV  0.490
     SMT  1.788
     KAL  1.788
     OTH  1.788/

  GLB(RG) Time dependence term of population
    /JAV  -0.056
     SMT  -0.037
     KAL  -0.049
     OTH  -0.025/

  CH(AT) Carbon Emission Coefficient (Ton Carbon per TOE)
    /COA-I  1.000
     COA-O  1.000
     GAS-I  0.578
     GAS-T  0.578
     GAS-O  0.578
     OIL-I  0.825
     OIL-T  0.825
     OIL-O  0.825
     BIO-O  0.000
     COA-P  1.000
     GAS-P  0.578
     OIL-P  0.825
     HYDRO  0.000
     GEOTR  0.000/

  BETA(T)     Annual discount factor
  AL(T)       Technical progress
  L(T,RG)     Level of population (Million)
  EFF(T,RG)   Electric power conversion efficiency
  DKT         Depreciation rate per decade
  SHARE       Income per capita in 1990
  NEGISHI(RG) Share of income percapita
  ;

TABLE RESF(FOSS,RG) Resource of fossil fuel (MTOE)
          JAV    SMT    KAL    OTH
  COAL     39  15762   5955     68
  NGAS    306   1580    601     22
  COIL    185   1161    140     11
  ;

TABLE ECST(ET,RG) Electricity cost coefficient (Dollar per TOE)
             JAV      SMT      KAL      OTH
  COA-P  550.000  550.000  550.000  550.000
  GAS-P  480.000  480.000  480.000  480.000
  OIL-P  500.000  500.000  500.000  500.000
  HYDRO  600.000  600.000  600.000  600.000
  GEOTR  580.000  580.000  580.000  580.000
  ;

TABLE NCST(NT,RG) Nonelectric cost coefficient (Dollar per TOE)
             JAV      SMT      KAL      OTH
  COA-I   83.720   83.720   83.720   83.720
  COA-O   83.720   83.720   83.720   83.720
  GAS-I   62.790   62.790   62.790   62.790
  GAS-T   62.790   62.790   62.790   62.790
  GAS-O   62.790   62.790   62.790   62.790
  OIL-I  104.650  104.650  104.650  104.650
  OIL-T  104.650  104.650  104.650  104.650
  OIL-O  104.650  104.650  104.650  104.650
  BIO-O   60.000   60.000   60.000   60.000
  ;

TABLE CTRD(FOSS,RG) Domestic transport. cost of fossil (dollar per TOE)
          JAV    SMT    KAL    OTH
  COAL  0.980  0.980  0.980  0.980
  NGAS  4.790  4.790  4.790  4.790
  COIL  0.670  0.670  0.670  0.670
  ;

TABLE CTRF(FOSS,RG) Foregin transport. cost of fossil (dollar per TOE)
          JAV    SMT    KAL    OTH
  COAL  1.960  1.960  1.960  1.960
  NGAS  9.580  9.580  9.580  9.580
  COIL  1.340  1.340  1.340  1.340
  ;

TABLE PRO0(AT,RG) Energy production in 1990 (MTOE)
            JAV      SMT      KAL      OTH
  COA-I   2.442    0.422    0.015    0.022
  COA-O   0.132    0.011    0.002    0.002
  GAS-I   3.852    0.942    0.542    0.582
  GAS-T   0.404    0.017    0.002    0.005
  GAS-O   2.604    1.102    0.002    0.003
  OIL-I   8.455    3.342    1.142    1.152
  OIL-T   8.708    2.570    1.073    1.782
  OIL-O   6.876    2.642    0.452    0.402
  BIO-O   7.130    6.342    1.642    1.924
  COA-P   0.612    0.322    0.107    0.112
  GAS-P   0.173    0.031    0.023    0.031
  OIL-P   2.708    0.712    0.409    0.442
  HYDRO   0.678    0.335    0.137    0.142
  GEOTR   0.868    0.012    0.001    0.022
  ;

TABLE DMD0(EDM,RG) Lower bound of electricity energy (MTOE)
            JAV      SMT      KAL      OTH
  ELE-I   0.792    0.154    0.015    0.103
  ELE-T   0.005    0.000    0.000    0.000
  ELE-O   0.672    0.125    0.015    0.103
  ;

TABLE IMD0(FOSS,RG) Lower bound of domestic import of fossil (MTOE)
           JAV     SMT     KAL     OTH
  COAL   0.000   0.000   0.000   0.000
  NGAS   0.000   0.000   0.000   0.000
  COIL   0.000   0.000   0.000   0.000
  ;

TABLE EXD0(FOSS,RG) Lower bound of domestic export of fossil (MTOE)
           JAV     SMT     KAL     OTH
  COAL   0.000   0.000   0.000   0.000
  NGAS   0.000   0.000   0.000   0.000
  COIL   0.000   0.000   0.000   0.000
  ;

TABLE IMF0(FOSS,RG) Lower bound of foreign import of fossil (MTOE) 
           JAV     SMT     KAL     OTH
  COAL   0.000   0.000   0.000   0.000
  NGAS   0.000   0.000   0.000   0.000
  COIL   0.000   0.000   0.000   0.000
  ;

TFIRST(T) = YES$(ORD(T) EQ 1);
TLAST(T)  = YES$(ORD(T) EQ CARD(T));
DISPLAY TFIRST, TLAST;

EFF(T,RG) = EFF0(RG)/(1+EFFA(RG)*EXP(EFFB(RG)*NYPER*(ORD(T)-1)));
L(T,RG)   = GL0(RG)/(1+GLA(RG)*EXP(GLB(RG)*NYPER*(ORD(T)-1)));
L0(RG)    = L('1990',RG);

BETA(T)     = BET**(NYPER*ORD(T));
BETA(TLAST) = BETA(TLAST)/(1-BET);

E0(RG) = SUM(ET, PRO0(ET,RG));
N0(RG) = SUM(NT, PRO0(NT,RG));
A(RG)  = Y0(RG)/((K0(RG)**KPVS(RG) * L0(RG)**(1-KPVS(RG)))**(1-ESUB(RG)) *
         (E0(RG)**ELVS(RG) * N0(RG)**(1-ELVS(RG)))**ESUB(RG));

DKT   = (1-DK)**NYPER;
AL(T) = A0 * EXP((GA0/DELA) * (1.-EXP(-DELA*(ORD(T)-1))));

SHARE = SUM(RG, Y0(RG)/L0(RG));
NEGISHI(RG) = (Y0(RG)/L0(RG))/SHARE;

DISPLAY E0, N0, BETA, A, AL, L, L0, EFF, DKT;

VARIABLES 
  PRO(AT,T,RG)   Energy production (MTOE)
  DMD(EDM,T,RG)  Energy demand (MTOE)
  EC(T,RG)       Energy cost
  TDC(T,RG)      Domestic transport cost
  TFC(T,RG)      Foreign transport cost
  EE(T,RG)       CO2 emission (Billion Ton of Carbon)

  IMD(FOSS,T,RG)  Domestic import of energy
  EXD(FOSS,T,RG)  Domestic export of energy
  IMF(FOSS,T,RG)  Foreign import of energy

  K(T,RG)        Capital stock 
  C(T,RG)        Consumption 
  I(T,RG)        Investment
  Y(T,RG)        Output (Million 1990 US dollar)
  UTILITY        Objective
  ;

POSITIVE VARIABLE
  K, C, I, Y, PRO, DMD, EC, EE, IMD, EXD, IMF
  ;

EQUATIONS 
  ECOST(T,RG)  Energy cost equation
  TDCOST(T,RG) Domestic transportation cost equation
  TFCOST(T,RG) Foreign transportation cost equation
  EEM(T,RG)    Carbon emission equation

  LMCOA(RG)    Limit of coal reserve
  LMGAS(RG)    Limit of gas reserve
  LMOIL(RG)    Limit of oil reserve
  LMBIO(T,RG)  Limit of biomass reserve
  LMGEO(T,RG)  Limit of geothermal reserve
  LMHYD(T,RG)  Limit of hydropower reserve

  IEDBAL(FOSS,T) Balance of regional transport. of fossil
  
  EBAL(T,RG)        Electricity balance
  PRDUP(AT,T,RG)    Upper bound of energy production
  DMDUP(EDM,T,RG)   Upper bound of electricity energy
  EXDUP(FOSS,T,RG)  Upper bound of domestic export
  IMDUP(FOSS,T,RG)  Upper bound of domestic import
  IMFUP(FOSS,T,RG)  Upper bound of foreign import

  IXCOA(T,RG)  Maximum domestic import of coal
  IXOIL(T,RG)  Maximum domestic import of oil
  IXGAS(T,RG)  Maximum domestic import of gas
  
  MXCOA(T,RG)  Maximum foreign import of coal
  MXOIL(T,RG)  Maximum foreign import of oil
  MXGAS(T,RG)  Maximum foreign import of gas

  CC(T,RG)  Capacity constraint
  KK(T,RG)  Capital balance
  TM(T,RG)  Terminal condition
  YY(T,RG)  Output equation

  TRNDMD(T,RG)   Demand on transportation sector
  PUBDMD(T,RG)   Demand on other sectors
  
  UTIL  Objective function equation
  ;

ECOST(T,RG)..  EC(T,RG) =E= (SUM(ET, ECST(ET,RG)*PRO(ET,T,RG)) +
               SUM(NT, NCST(NT,RG)*PRO(NT,T,RG)) + PFFC*TFC(T,RG) + 
               PFDC*TDC(T,RG) )*NYPER/PFEC;

TDCOST(T,RG).. TDC(T,RG) =E= SUM(FOSS, (CTRD(FOSS,RG)*IMD(FOSS,T,RG) +
               CTRD(FOSS,RG)*EXD(FOSS,T,RG)));
TFCOST(T,RG).. TFC(T,RG) =E= SUM(FOSS, CTRF(FOSS,RG)*IMF(FOSS,T,RG));

EEM(T,RG)..    EE(T,RG) =E= SUM(AT, CH(AT)*PRO(AT,T,RG));
                     
LMCOA(RG)..    SUM(T, (SUM(TCOA, PRO(TCOA,T,RG)) -
               IMD('COAL',T,RG)+EXD('COAL',T,RG)-IMF('COAL',T,RG) )*
               NYPER) =L= RESF('COAL',RG);
LMGAS(RG)..    SUM(T, (SUM(TGAS, PRO(TGAS,T,RG)) -
               IMD('NGAS',T,RG)+EXD('NGAS',T,RG)-IMF('NGAS',T,RG) )*
               NYPER) =L= RESF('NGAS',RG);
LMOIL(RG)..    SUM(T, (SUM(TOIL, PRO(TOIL,T,RG)) -
               IMD('COIL',T,RG)+EXD('COIL',T,RG)-IMF('COIL',T,RG) )*
               NYPER) =L= RESF('COIL',RG);

LMBIO(T,RG)..  PRO('BIO-O',T,RG) =L= RESBIO(RG);
LMGEO(T,RG)..  PRO('GEOTR',T,RG) =L= RESGEO(RG);
LMHYD(T,RG)..  PRO('HYDRO',T,RG) =L= RESHYD(RG);

IEDBAL(FOSS,T).. SUM(RG, IMD(FOSS,T,RG)-EXD(FOSS,T,RG)) =E= 0;

EBAL(T,RG)..   SUM(EDM, DMD(EDM,T,RG)) =E= EFF(T,RG)*SUM(ET, PRO(ET,T,RG));
PRDUP(AT,T+1,RG).. PRO(AT,T+1,RG) =G= PRO(AT,T,RG)*DKT;

DMDUP(EDM,T+1,RG).. DMD(EDM,T+1,RG) =G= DMD(EDM,T,RG)*1.05;

EXDUP(FOSS,T+1,RG).. EXD(FOSS,T+1,RG) =G= EXD(FOSS,T,RG)*DKT;
IMDUP(FOSS,T+1,RG).. IMD(FOSS,T+1,RG) =G= IMD(FOSS,T,RG)*DKT;
IMFUP(FOSS,T+1,RG).. IMF(FOSS,T+1,RG) =G= IMF(FOSS,T,RG)*DKT;

IXCOA(T,RG).. IMD('COAL',T,RG) =L= SUM(TCOA, PRO(TCOA,T,RG));
IXOIL(T,RG).. IMD('COIL',T,RG) =L= SUM(TOIL, PRO(TOIL,T,RG));
IXGAS(T,RG).. IMD('NGAS',T,RG) =L= SUM(TGAS, PRO(TGAS,T,RG));

MXCOA(T,RG).. IMF('COAL',T,RG) =L= SUM(TCOA, PRO(TCOA,T,RG));
MXOIL(T,RG).. IMF('COIL',T,RG) =L= SUM(TOIL, PRO(TOIL,T,RG));
MXGAS(T,RG).. IMF('NGAS',T,RG) =L= SUM(TGAS, PRO(TGAS,T,RG));

YY(T,RG)..  Y(T,RG) =E= A(RG)*AL(T) * (K(T,RG)**KPVS(RG) *
            L(T,RG)**(1-KPVS(RG)))**(1-ESUB(RG)) *
            (DMD('ELE-I',T,RG)**ELVS(RG) *
            SUM(NIND, PRO(NIND,T,RG))**(1-ELVS(RG)))**ESUB(RG);

TRNDMD(T,RG).. SUM(NTRA, PRO(NTRA,T,RG))+DMD('ELE-T',T,RG) =G=
               PFPF*A(RG)*AL(T)*Y(T,RG)**EATRN(RG)*L(T,RG)**(1-EATRN(RG));

PUBDMD(T,RG).. SUM(NOTH, PRO(NOTH,T,RG))+DMD('ELE-O',T,RG) =G=
               PFPF*A(RG)*AL(T)*Y(T,RG)**EAPUB(RG)*L(T,RG)**(1-EAPUB(RG));

CC(T,RG)..      Y(T,RG)  =E=  C(T,RG) + I(T,RG) + EC(T,RG);
KK(T+1,RG)..    K(T+1,RG) =E=  DKT*K(T,RG) + NYPER*I(T,RG);
TM(TLAST,RG)..  R(RG) * K(TLAST,RG) =L=  I(TLAST,RG);

UTIL..   UTILITY =E=  SUM((T,RG), NEGISHI(RG)*L(T,RG)*BETA(T)*
                      LOG(C(T,RG)/L(T,RG)))
                      ;

** Initialization of Variable **

K.LO(T,RG) = K0(RG);
C.LO(T,RG) = C0(RG);
I.LO(T,RG) = I0(RG);
Y.LO(T,RG) = Y0(RG);
Y.FX(TFIRST,RG) = Y.LO(TFIRST,RG);

PRO.LO(AT,T,RG) = PRO0(AT,RG);
PRO.FX(AT,TFIRST,RG) = PRO.LO(AT,TFIRST,RG);

DMD.LO(EDM,T,RG) = DMD0(EDM,RG);

IMD.LO(FOSS,T,RG) = IMD0(FOSS,RG);
IMD.FX(FOSS,TFIRST,RG) = IMD.LO(FOSS,TFIRST,RG);

EXD.LO(FOSS,T,RG) = EXD0(FOSS,RG);
EXD.FX(FOSS,TFIRST,RG) = EXD.LO(FOSS,TFIRST,RG);

IMF.LO(FOSS,T,RG) = IMF0(FOSS,RG);
IMF.FX(FOSS,TFIRST,RG) = IMF.LO(FOSS,TFIRST,RG);

OPTION ITERLIM  = 100000;
OPTION RESLIM   = 999999;
OPTION SOLPRINT = OFF;

MODEL ENERGY /ALL/;

SOLVE ENERGY MAXIMIZING UTILITY USING NLP;

** Result Report **

PUT /;
PUT " Aggregate " /;
PUT "-----------" /;
PUT "Total primary energy production (MTOE)" /;
PUT " Year      Coal      Gas      Oil   Hydro.  Geothm.  Biomass     Total" /;
LOOP(T, 
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT SUM((TCOA,RG), PRO.L(TCOA,T,RG)):10:3;
  PUT SUM((TGAS,RG), PRO.L(TGAS,T,RG)):9:3;
  PUT SUM((TOIL,RG), PRO.L(TOIL,T,RG)):9:3;
  PUT SUM(RG, PRO.L('HYDRO',T,RG)):9:3;
  PUT SUM(RG, PRO.L('GEOTR',T,RG)):9:3;
  PUT SUM(RG, PRO.L('BIO-O',T,RG)):9:3;
  PUT SUM((AT,RG), PRO.L(AT,T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Economic indicator and CO2 emission" /;
PUT " Year    Income    Popul.  Ele_eff. Y_per_cap   CO2_Em." /;
LOOP(T, 
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT SUM(RG, Y.L(T,RG)):10:3;
  PUT SUM(RG, L(T,RG)):10:3;
  PUT (SUM(RG, EFF(T,RG))/4):10:3;
  PUT (1000*SUM(RG, Y.L(T,RG))/SUM(RG, L(T,RG))):10:3;
  PUT SUM(RG, EE.L(T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Energy demand each sector & Elec-nonelec. energy (MTOE)" /;
PUT " Year   Indust.  Transp.    Other    Total      Elec.  Non-ele" /;
LOOP(T,
 PUT (ORD(T)*NYPER+1980):5:0;
 PUT (SUM(RG, SUM(NIND, PRO.L(NIND,T,RG))+DMD.L('ELE-I',T,RG)/EFF(T,RG))):10:3;
 PUT (SUM(RG, SUM(NTRA, PRO.L(NTRA,T,RG))+DMD.L('ELE-T',T,RG)/EFF(T,RG))):9:3;
 PUT (SUM(RG, SUM(NOTH, PRO.L(NOTH,T,RG))+DMD.L('ELE-O',T,RG)/EFF(T,RG))):9:3;
 PUT (SUM(RG, SUM(NIND, PRO.L(NIND,T,RG))+DMD.L('ELE-I',T,RG)/EFF(T,RG) +
              SUM(NTRA, PRO.L(NTRA,T,RG))+DMD.L('ELE-T',T,RG)/EFF(T,RG) +
              SUM(NOTH, PRO.L(NOTH,T,RG))+DMD.L('ELE-O',T,RG)/EFF(T,RG))):9:3;
 PUT SUM((ET,RG), PRO.L(ET,T,RG)):11:3;
 PUT SUM((NT,RG), PRO.L(NT,T,RG)):9:3;
 PUT /;
);

PUT /;
PUT " Regional " /;
PUT "----------" /;
PUT "Regional of primary energy production (MTOE)" /;
LOOP(RG,
  PUT "REGION =";
  PUT ORD(RG):2:0 /;
  PUT " Year     Coal      Gas      Oil   Hydro.     Geo.  Biomass    Total"/;
  LOOP(T, 
    PUT (ORD(T)*NYPER+1980):5:0;
    PUT SUM(TCOA, PRO.L(TCOA,T,RG)):9:3;
    PUT SUM(TGAS, PRO.L(TGAS,T,RG)):9:3;
    PUT SUM(TOIL, PRO.L(TOIL,T,RG)):9:3;
    PUT PRO.L('HYDRO',T,RG):9:3;
    PUT PRO.L('GEOTR',T,RG):9:3;
    PUT PRO.L('BIO-O',T,RG):9:3;
    PUT (SUM(TCOA, PRO.L(TCOA,T,RG))+SUM(TGAS, PRO.L(TGAS,T,RG))+
         SUM(TOIL, PRO.L(TOIL,T,RG))+PRO.L('HYDRO',T,RG)+
         PRO.L('GEOTR',T,RG)+PRO.L('BIO-O',T,RG)):9:3;
    PUT /;
  );
);

PUT /;
PUT "Regional of economic indicator & exogenous variable" /;
PUT "Income (Million 1990 US dollar)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT Y.L(T,'JAV'):10:3;
  PUT Y.L(T,'SMT'):10:3;
  PUT Y.L(T,'KAL'):10:3;
  PUT Y.L(T,'OTH'):10:3;
  PUT SUM(RG, Y.L(T,RG)):10:3;
  PUT /;
);
PUT "Income per capita (1990 US dollar)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT (1000*Y.L(T,'JAV')/L(T,'JAV')):10:3;
  PUT (1000*Y.L(T,'SMT')/L(T,'SMT')):10:3;
  PUT (1000*Y.L(T,'KAL')/L(T,'KAL')):10:3;
  PUT (1000*Y.L(T,'OTH')/L(T,'OTH')):10:3;
  PUT /;
);
PUT "Population (million)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT L(T,'JAV'):10:3;
  PUT L(T,'SMT'):10:3;
  PUT L(T,'KAL'):10:3;
  PUT L(T,'OTH'):10:3;
  PUT SUM(RG, L(T,RG)):10:3;
  PUT /;
);
PUT "Electricity use efficiency (%)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland   Average" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT EFF(T,'JAV'):10:3;
  PUT EFF(T,'SMT'):10:3;
  PUT EFF(T,'KAL'):10:3;
  PUT EFF(T,'OTH'):10:3;
  PUT (SUM(RG, EFF(T,RG))/4):10:3;
  PUT /;
);

PUT /;
PUT "CO2 Emission (Billion TON)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT EE.L(T,'JAV'):10:3;
  PUT EE.L(T,'SMT'):10:3;
  PUT EE.L(T,'KAL'):10:3;
  PUT EE.L(T,'OTH'):10:3;
  PUT SUM(RG, EE.L(T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Domestic import of coal (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT IMD.L('COAL',T,'JAV'):10:3;
  PUT IMD.L('COAL',T,'SMT'):10:3;
  PUT IMD.L('COAL',T,'KAL'):10:3;
  PUT IMD.L('COAL',T,'OTH'):10:3;
  PUT SUM(RG, IMD.L('COAL',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Domestic import of oil (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT IMD.L('COIL',T,'JAV'):10:3;
  PUT IMD.L('COIL',T,'SMT'):10:3;
  PUT IMD.L('COIL',T,'KAL'):10:3;
  PUT IMD.L('COIL',T,'OTH'):10:3;
  PUT SUM(RG, IMD.L('COIL',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Domestic import of gas (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT IMD.L('NGAS',T,'JAV'):10:3;
  PUT IMD.L('NGAS',T,'SMT'):10:3;
  PUT IMD.L('NGAS',T,'KAL'):10:3;
  PUT IMD.L('NGAS',T,'OTH'):10:3;
  PUT SUM(RG, IMD.L('NGAS',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Domestic export of coal (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT EXD.L('COAL',T,'JAV'):10:3;
  PUT EXD.L('COAL',T,'SMT'):10:3;
  PUT EXD.L('COAL',T,'KAL'):10:3;
  PUT EXD.L('COAL',T,'OTH'):10:3;
  PUT SUM(RG, EXD.L('COAL',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Domestic export of oil (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT EXD.L('COIL',T,'JAV'):10:3;
  PUT EXD.L('COIL',T,'SMT'):10:3;
  PUT EXD.L('COIL',T,'KAL'):10:3;
  PUT EXD.L('COIL',T,'OTH'):10:3;
  PUT SUM(RG, EXD.L('COIL',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Domestic export of gas (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT EXD.L('NGAS',T,'JAV'):10:3;
  PUT EXD.L('NGAS',T,'SMT'):10:3;
  PUT EXD.L('NGAS',T,'KAL'):10:3;
  PUT EXD.L('NGAS',T,'OTH'):10:3;
  PUT SUM(RG, EXD.L('NGAS',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Foreign import of coal (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT IMF.L('COAL',T,'JAV'):10:3;
  PUT IMF.L('COAL',T,'SMT'):10:3;
  PUT IMF.L('COAL',T,'KAL'):10:3;
  PUT IMF.L('COAL',T,'OTH'):10:3;
  PUT SUM(RG, IMF.L('COAL',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Foreign import of oil (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT IMF.L('COIL',T,'JAV'):10:3;
  PUT IMF.L('COIL',T,'SMT'):10:3;
  PUT IMF.L('COIL',T,'KAL'):10:3;
  PUT IMF.L('COIL',T,'OTH'):10:3;
  PUT SUM(RG, IMF.L('COIL',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Foreign import of gas (MTOE)" /;
PUT " Year      Java  Sumatera  Kalimant OthIsland     Total" /;
LOOP(T,
  PUT (ORD(T)*NYPER+1980):5:0;
  PUT IMF.L('NGAS',T,'JAV'):10:3;
  PUT IMF.L('NGAS',T,'SMT'):10:3;
  PUT IMF.L('NGAS',T,'KAL'):10:3;
  PUT IMF.L('NGAS',T,'OTH'):10:3;
  PUT SUM(RG, IMF.L('NGAS',T,RG)):10:3;
  PUT /;
);

PUT /;
PUT "Demand sector (MTOE) " /;
LOOP(RG,
  PUT "REGION =";
  PUT ORD(RG):2:0 /;
  PUT " Year    Industry   Transport OtherSector" /;
  LOOP(T,
    PUT (ORD(T)*NYPER+1980):5:0;
    PUT (SUM(NIND, PRO.L(NIND,T,RG))+DMD.L('ELE-I',T,RG)/EFF(T,RG)):12:3;
    PUT (SUM(NTRA, PRO.L(NTRA,T,RG))+DMD.L('ELE-T',T,RG)/EFF(T,RG)):12:3;
    PUT (SUM(NOTH, PRO.L(NOTH,T,RG))+DMD.L('ELE-O',T,RG)/EFF(T,RG)):12:3;
    PUT /;
  );
);

PUT /;
PUT "Electricity & nonelectricity energy (MTOE)" /;
LOOP(RG,
  PUT "REGION =";
  PUT ORD(RG):2:0 /;
  PUT " Year       Industry       Transport          Other          Total"/;
  PUT "          ELE     NON     ELE     NON     ELE     NON     ELE     NON"/;
  LOOP(T,
    PUT (ORD(T)*NYPER+1980):5:0;
    PUT (DMD.L('ELE-I',T,RG)/EFF(T,RG)):8:3;
    PUT SUM(NIND, PRO.L(NIND,T,RG)):8:3;
    PUT (DMD.L('ELE-T',T,RG)/EFF(T,RG)):8:3;
    PUT SUM(NTRA, PRO.L(NTRA,T,RG)):8:3;
    PUT (DMD.L('ELE-O',T,RG)/EFF(T,RG)):8:3;
    PUT SUM(NOTH, PRO.L(NOTH,T,RG)):8:3;
    PUT SUM(ET, PRO.L(ET,T,RG)):8:3;
    PUT SUM(NT, PRO.L(NT,T,RG)):8:3;
    PUT /;
  );
);

PUT /;
PUT "Electricity energy production by fuel (MTOE)" /;
LOOP(RG,
  PUT "REGION =";
  PUT ORD(RG):2:0 /;
  PUT " Year    Coal     Gas     Oil   Hydr.  Geoth.    Total" /;
  LOOP(T,
    PUT (ORD(T)*NYPER+1980):5:0;
    PUT PRO.L('COA-P',T,RG):8:3;
    PUT PRO.L('GAS-P',T,RG):8:3;
    PUT PRO.L('OIL-P',T,RG):8:3;
    PUT PRO.L('HYDRO',T,RG):8:3;
    PUT PRO.L('GEOTR',T,RG):8:3;
    PUT SUM(ET, PRO.L(ET,T,RG)):9:3;
    PUT /;
  );
);

PUT /;
PUT "Production of all energy technology (MTOE)" /;
LOOP(RG,
  PUT /;
  PUT "REGION =";
  PUT ORD(RG):2:0 /;
  PUT " Year  COAL-IND  COAL-OTH   GAS-IND   GAS-TRA   GAS-OTH " /;
  LOOP(T,
    PUT (ORD(T)*NYPER+1980):5:0;
    PUT PRO.L('COA-I',T,RG):10:3;
    PUT PRO.L('COA-O',T,RG):10:3;
    PUT PRO.L('GAS-I',T,RG):10:3;
    PUT PRO.L('GAS-T',T,RG):10:3;
    PUT PRO.L('GAS-O',T,RG):10:3;
    PUT /;
  );
  PUT /;
  PUT " Year   OIL-IND   OIL-TRA   OIL-OTH   BIO-OTH " /;
  LOOP(T,
    PUT (ORD(T)*NYPER+1980):5:0;
    PUT PRO.L('OIL-I',T,RG):10:3;
    PUT PRO.L('OIL-T',T,RG):10:3;
    PUT PRO.L('OIL-O',T,RG):10:3;
    PUT PRO.L('BIO-O',T,RG):10:3;
    PUT /;
  );
  PUT /;
  PUT " Year    COAL-P     GAS-P     OIL-P     HYDRO     GEOTR" /;
  LOOP(T,
    PUT (ORD(T)*NYPER+1980):5:0;
    PUT PRO.L('COA-P',T,RG):10:3;
    PUT PRO.L('GAS-P',T,RG):10:3;
    PUT PRO.L('OIL-P',T,RG):10:3;
    PUT PRO.L('HYDRO',T,RG):10:3;
    PUT PRO.L('GEOTR',T,RG):10:3;
    PUT /;
  );
);

